@@ -8,7 +8,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = "2.000";
+our $VERSION = "2.002";
 $VERSION = eval $VERSION;
 
 use LWP::UserAgent;
@@ -63,8 +63,8 @@ sub send_sms {
     # example: 1111:gOwn:420111222333 
     my @id = split(':', $self->{'login'});  
     my $app_id = $id[0]; 
-    my $sender_id = defined $id[1] ? $id[1] : 'gText';
-    my $sender_id_value = defined $id[2] ? $id[2] : 'BulkGate';
+    my $sender_id = defined $id[1] ? $id[1] : 'gSystem';
+    my $sender_id_value = defined $id[2] ? $id[2] : undef;
 
 	my %params = (
 	    'application_id'       => $id[0],
@@ -123,7 +123,7 @@ SMS::Send::CZ::Bulkgate - SMS::Send driver for Bulkgate - Czech Republic
 
 =head1 VERSION
 
-version 2.001
+version 2.002
 
 =head1 SYNOPSIS
 
@@ -155,8 +155,8 @@ Logs message to /var/log/bulkgate.log if this file is accessible and writable
 
 =head2 send_sms
 
-Sends the message using prividers API at https://api.bulkgate.com/http and takes additional arguments:
-'text' containgin the message itself and 'to' with recipient's number.
+Sends the message using BulkGate Simple API at https://portal.bulkgate.com/api/1.0/simple/transactional and takes additional arguments:
+'text' containing the message itself and 'to' providing recipient's number.
 
 Processing information is automatically logged to /var/log/bulkgate.log to allow tracking of possible problems.   
 
